powered by
Normalize and analyze FRAP data. Perform non-linear regression and calculate ymax, ymin, k, halftime, tau, total_recovery, total_recovery_sd.
frapprocess(ds, time_points)
A dataset that contains FRAP data for multiple experiment groups
A vector of time points (in second) that the experiment uses, e.g. 0, 5, 10, ....
A list of results:
$time_points: a vector of time points
$summary: summary of the regression
$sample_means: a matrix of sample means, nrow = num of time points, ncol = sample size
$sample_sd: a matrix of standard deviations, nrow = num of time points, ncol = sample size
$model: a list of models for each group from the non-linear regression
$details: details of the regression for each group
# NOT RUN { info <- frapprocess(example_dataset, seq(0, 145, 5)) # }
Run the code above in your browser using DataLab